
:autogenerated:

weylchamber.gates module
========================

.. currentmodule:: weylchamber.gates

.. automodule:: weylchamber.gates
    :members: bell_basis, gate, mapped_basis
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        bell_basis
        gate
        mapped_basis





    ``__all__``: :data:`Qmagic <Qmagic>`, :data:`SxSx <SxSx>`, :data:`SySy <SySy>`, :data:`SzSz <SzSz>`, :func:`bell_basis <weylchamber.gates.bell_basis>`, :func:`gate <weylchamber.gates.gate>`, :func:`mapped_basis <weylchamber.gates.mapped_basis>`



    Reference
    ---------